/****************************************************************************
** Meta object code from reading C++ file 'maildirresource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdepim-runtime-26.04.0/resources/maildir/maildirresource.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'maildirresource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15MaildirResourceE_t {};
} // unnamed namespace

template <> constexpr inline auto MaildirResource::qt_create_metaobjectdata<qt_meta_tag_ZN15MaildirResourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MaildirResource",
        "retrieveCollections",
        "",
        "retrieveItems",
        "Akonadi::Collection",
        "col",
        "Akonadi::Item::List",
        "items",
        "QSet<QByteArray>",
        "parts",
        "configurationChanged",
        "slotItemsRetrievalResult",
        "KJob*",
        "job",
        "slotDirChanged",
        "dir",
        "slotFileChanged",
        "QFileInfo",
        "fileInfo",
        "fsWatchDirFetchResult",
        "fsWatchFileFetchResult",
        "fsWatchFileModifyResult",
        "attemptConfigRestoring",
        "changedCleaner"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'retrieveCollections'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'retrieveItems'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(3, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'retrieveItems'
        QtMocHelpers::SlotData<bool(const Akonadi::Item::List &, const QSet<QByteArray> &)>(3, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'configurationChanged'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotItemsRetrievalResult'
        QtMocHelpers::SlotData<void(KJob *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'slotDirChanged'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'slotFileChanged'
        QtMocHelpers::SlotData<void(const QFileInfo &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'fsWatchDirFetchResult'
        QtMocHelpers::SlotData<void(KJob *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'fsWatchFileFetchResult'
        QtMocHelpers::SlotData<void(KJob *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'fsWatchFileModifyResult'
        QtMocHelpers::SlotData<void(KJob *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'attemptConfigRestoring'
        QtMocHelpers::SlotData<void(KJob *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'changedCleaner'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MaildirResource, qt_meta_tag_ZN15MaildirResourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MaildirResource::staticMetaObject = { {
    QMetaObject::SuperData::link<Akonadi::ResourceBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MaildirResourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MaildirResourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15MaildirResourceE_t>.metaTypes,
    nullptr
} };

void MaildirResource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MaildirResource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->retrieveCollections(); break;
        case 1: _t->retrieveItems((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        case 2: { bool _r = _t->retrieveItems((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSet<QByteArray>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->configurationChanged(); break;
        case 4: _t->slotItemsRetrievalResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 5: _t->slotDirChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->slotFileChanged((*reinterpret_cast<std::add_pointer_t<QFileInfo>>(_a[1]))); break;
        case 7: _t->fsWatchDirFetchResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 8: _t->fsWatchFileFetchResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 9: _t->fsWatchFileModifyResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 10: _t->attemptConfigRestoring((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 11: _t->changedCleaner(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QByteArray> >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *MaildirResource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MaildirResource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MaildirResourceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Akonadi::AgentBase::ObserverV2"))
        return static_cast< Akonadi::AgentBase::ObserverV2*>(this);
    return Akonadi::ResourceBase::qt_metacast(_clname);
}

int MaildirResource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Akonadi::ResourceBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
