/****************************************************************************
** Meta object code from reading C++ file 'personhandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdepim-runtime-26.04.0/resources/google-groupware/personhandler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'personhandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13PersonHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto PersonHandler::qt_create_metaobjectdata<qt_meta_tag_ZN13PersonHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PersonHandler",
        "sendModifyJob",
        "",
        "Akonadi::Item::List",
        "items",
        "KGAPI2::People::PersonList",
        "people",
        "Akonadi::Item",
        "item",
        "KGAPI2::People::PersonPtr",
        "person",
        "slotItemsRetrieved",
        "KGAPI2::Job*",
        "job",
        "slotPersonCreateJobFinished",
        "slotKGAPIModifyJobFinished",
        "processUpdatedPeople",
        "KGAPI2::ObjectsList",
        "updatedPeople",
        "updatePersonItem",
        "originalItem",
        "updateContactGroupCollection",
        "Akonadi::Collection",
        "collection",
        "KGAPI2::People::ContactGroupPtr",
        "group"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'sendModifyJob'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const KGAPI2::People::PersonList &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'sendModifyJob'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const KGAPI2::People::PersonPtr &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotItemsRetrieved'
        QtMocHelpers::SlotData<void(KGAPI2::Job *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'slotPersonCreateJobFinished'
        QtMocHelpers::SlotData<void(KGAPI2::Job *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'slotKGAPIModifyJobFinished'
        QtMocHelpers::SlotData<void(KGAPI2::Job *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'processUpdatedPeople'
        QtMocHelpers::SlotData<void(KGAPI2::Job *, const KGAPI2::ObjectsList &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'updatePersonItem'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, const KGAPI2::People::PersonPtr &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 20 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'updateContactGroupCollection'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &, const KGAPI2::People::ContactGroupPtr &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PersonHandler, qt_meta_tag_ZN13PersonHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PersonHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<GenericHandler::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PersonHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PersonHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13PersonHandlerE_t>.metaTypes,
    nullptr
} };

void PersonHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PersonHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sendModifyJob((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KGAPI2::People::PersonList>>(_a[2]))); break;
        case 1: _t->sendModifyJob((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KGAPI2::People::PersonPtr>>(_a[2]))); break;
        case 2: _t->slotItemsRetrieved((*reinterpret_cast<std::add_pointer_t<KGAPI2::Job*>>(_a[1]))); break;
        case 3: _t->slotPersonCreateJobFinished((*reinterpret_cast<std::add_pointer_t<KGAPI2::Job*>>(_a[1]))); break;
        case 4: _t->slotKGAPIModifyJobFinished((*reinterpret_cast<std::add_pointer_t<KGAPI2::Job*>>(_a[1]))); break;
        case 5: _t->processUpdatedPeople((*reinterpret_cast<std::add_pointer_t<KGAPI2::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KGAPI2::ObjectsList>>(_a[2]))); break;
        case 6: _t->updatePersonItem((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KGAPI2::People::PersonPtr>>(_a[2]))); break;
        case 7: _t->updateContactGroupCollection((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KGAPI2::People::ContactGroupPtr>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
}

const QMetaObject *PersonHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PersonHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PersonHandlerE_t>.strings))
        return static_cast<void*>(this);
    return GenericHandler::qt_metacast(_clname);
}

int PersonHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GenericHandler::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
