/****************************************************************************
** Meta object code from reading C++ file 'ewsresourceadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "ewsresourceadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ewsresourceadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18EwsResourceAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto EwsResourceAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN18EwsResourceAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EwsResourceAdaptor",
        "D-Bus Interface",
        "org.kde.Akonadi.Ews.Resource",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.Akonadi.Ews.Resource\">\n    <signal n"
        "ame=\"messageSent\">\n      <arg direction=\"out\" type=\"s\" name"
        "=\"id\"/>\n      <arg direction=\"out\" type=\"s\" name=\"error\"/"
        ">\n    </signal>\n    <method name=\"clearCollectionSyncState\">\n"
        "      <arg direction=\"in\" type=\"i\" name=\"collectionId\"/>\n  "
        "  </method>\n    <method name=\"clearFolderTreeSyncState\"/>\n    "
        "<method name=\"setInitialReconnectTimeout\">\n      <arg direction"
        "=\"in\" type=\"i\" name=\"timeout\"/>\n    </method>\n    <method "
        "name=\"sendMessage\">\n      <arg direction=\"in\" type=\"s\" name"
        "=\"id\"/>\n      <arg direction=\"in\" type=\"ay\" name=\"content\""
        "/>\n    </method>\n  </interface>\n",
        "messageSent",
        "",
        "id",
        "error",
        "clearCollectionSyncState",
        "collectionId",
        "clearFolderTreeSyncState",
        "sendMessage",
        "content",
        "setInitialReconnectTimeout",
        "timeout"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'messageSent'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'clearCollectionSyncState'
        QtMocHelpers::SlotData<void(int)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'clearFolderTreeSyncState'
        QtMocHelpers::SlotData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendMessage'
        QtMocHelpers::SlotData<void(const QString &, const QByteArray &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QByteArray, 13 },
        }}),
        // Slot 'setInitialReconnectTimeout'
        QtMocHelpers::SlotData<void(int)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<EwsResourceAdaptor, qt_meta_tag_ZN18EwsResourceAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject EwsResourceAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18EwsResourceAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18EwsResourceAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18EwsResourceAdaptorE_t>.metaTypes,
    nullptr
} };

void EwsResourceAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EwsResourceAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->messageSent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->clearCollectionSyncState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->clearFolderTreeSyncState(); break;
        case 3: _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 4: _t->setInitialReconnectTimeout((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EwsResourceAdaptor::*)(const QString & , const QString & )>(_a, &EwsResourceAdaptor::messageSent, 0))
            return;
    }
}

const QMetaObject *EwsResourceAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EwsResourceAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18EwsResourceAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int EwsResourceAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void EwsResourceAdaptor::messageSent(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
